==> Epics.uv8.68.tar.gz: epics/ZepTrackv.h <==
#include "ZepMaxdef.h"

       integer Maxmedia, BitPhotoElec, BitPhoton,
     *    BitElectron, BitPositron, BitProton,
     *    BitNeutron, BitAntiNuc, BitDecay,
     *    BitOther
       parameter(  Maxmedia = MAX_MEDIA,
     *  BitPhotoElec=1, BitPhoton=2, BitElectron=3, BitPositron=3,
     *  BitProton=4, BitNeutron=5, BitAntiNuc=6, 
     *  BitDecay=7, BitOther=8  )
#include "Zmedia.h"
#include "ZepTrack.h"
#include "Zmove.h"
#include "Zep3Vec.h"

c          common variables used in tracking ptcls.
       record /epTrack/ cTrack    !  current track
       record /epTrack/ Incident  ! to keep 1st stacked track
       record /epmove/ Move         ! to contain info for moving a
                                  ! track  
                   
	real*8  Ethin         ! Thin sampling threshold.
	real*8  Beta  !  v/c for MovedTrack; given if TimeStrucrue=T.
        real*8  Tcoefx, Tminx  ! used to truncate path


        integer Cn        !  current particle cn
        record /epmedia/Media(Maxmedia)
        integer MediaNo   !  current particle media no = Cn2media(cn)
        logical Firsti, FirstC ! to set  first  collision/interaction 

        character*8  Proc1 ! to keep first interaction type
        record /epPos/ FirstInt !  to keep first int. pos.
        record /ep3Vec/ Bfield   !  Bfield.x, y, z  the B in  Tesla
                                !    in local coordinate 
        real*8   pathInB        !  total path length in B for a particle 
        record /ep3Vec/ Efield   !  Efiled.x, y, z  the E in V/m
                                !   local coordinate.
        real*8 SumDe       !  sum  of all energy deposit

        real*8 MaxPath     !  MaxPathL of a comp. is converted into r.l
        real*8 Upsilon     !  Ee/me * B/Bcr for use with sync.
        real*8 Xai         !  Eg/me * B/Bcr/2
        integer Bndryerr   ! counter for unsuccessful boundary search in
	                   ! an  event.  Failure may occure if a particle
			   ! is just on a boundary of a component by chance.
  		           ! If this happens so many times in an event,
                           ! something wrong may be happing so that we
			     ! stop the executon ( in epbndry ).	       
c
       common /ZepTrackv/ Media, Incident, cTrack, Move, 
     *  Bfield, Efield,
     *  FirstInt, MaxPath, Upsilon, Xai,  pathInB,
     *  Beta, Tcoefx, Tminx,  SumDe, Cn, MediaNo,
     *  Ethin, Firsti, FirstC, Bndryerr

       common /ZepTrackvC/ Proc1

==> Epics.uv8.77.tar.gz: epics/ZepTrackv.h <==
#include "ZepMaxdef.h"

       integer Maxmedia, BitPhotoElec, BitPhoton,
     *    BitElectron, BitPositron, BitProton,
     *    BitNeutron, BitAntiNuc, BitDecay,
     *    BitOther
       parameter(  Maxmedia = MAX_MEDIA,
     *  BitPhotoElec=1, BitPhoton=2, BitElectron=3, BitPositron=3,
     *  BitProton=4, BitNeutron=5, BitAntiNuc=6, 
     *  BitDecay=7, BitOther=8  )
#include "Zmedia.h"
#include "ZepTrack.h"
#include "Zmove.h"
#include "Zep3Vec.h"

c          common variables used in tracking ptcls.
       record /epTrack/ cTrack    !  current track
       record /epTrack/ Incident  ! to keep 1st stacked track
       record /epmove/ Move         ! to contain info for moving a
                                  ! track  
                   
	real*8  Ethin         ! Thin sampling threshold.
	real*8  Beta  !  v/c for MovedTrack; given if TimeStrucrue=T.
        real*8  Tcoefx, Tminx  ! used to truncate path


        integer Cn        !  current particle cn
        record /epmedia/Media(Maxmedia)
        integer MediaNo   !  current particle media no = Cn2media(cn)
        logical Firsti, FirstC ! to set  first  collision/interaction 
        record /epmedia/FirstMedia  ! first collision media
        character*8  Proc1 ! to keep first interaction type
        record /epPos/ FirstInt !  to keep first int. pos.
        					       
        record /ep3Vec/ Bfield   !  Bfield.x, y, z  the B in  Tesla
                                !    in local coordinate 
        real*8   pathInB        !  total path length in B for a particle 
        record /ep3Vec/ Efield   !  Efiled.x, y, z  the E in V/m
                                !   local coordinate.
        real*8 SumDe       !  sum  of all energy deposit

        real*8 MaxPath     !  MaxPathL of a comp. is converted into r.l
        real*8 Upsilon     !  Ee/me * B/Bcr for use with sync.
        real*8 Xai         !  Eg/me * B/Bcr/2
        integer Bndryerr   ! counter for unsuccessful boundary search in
	                   ! an  event.  Failure may occure if a particle
			   ! is just on a boundary of a component by chance.
  		           ! If this happens so many times in an event,
                           ! something wrong may be happing so that we
			     ! stop the executon ( in epbndry ).	       
c
       common /ZepTrackv/ Media, FirstMedia,
     *  Incident, cTrack, Move, 
     *  Bfield, Efield,
     *  FirstInt, MaxPath, Upsilon, Xai,  pathInB,
     *  Beta, Tcoefx, Tminx,  SumDe, Cn, MediaNo,
     *  Ethin, Firsti, FirstC, Bndryerr

       common /ZepTrackvC/ Proc1
